@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Parser;
 
-our $VERSION = '0.006_002'; # TRIAL VERSION
+our $VERSION = '0.006_003'; # TRIAL VERSION
 
 use constant TRACE => $ENV{YAML_PP_TRACE};
 use constant DEBUG => $ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE};
@@ -324,7 +324,10 @@ sub check_indent {
     if ($self->new_node) {
         # unindented sequence starts
         my $seq_start = $next_token->{name} eq 'DASH';
-        if ($space == $indent and $seq_start and $exp eq 'MAPVALUE') {
+        if (
+            $space == $indent and $seq_start
+            and ($exp eq 'MAPVALUE' or $exp eq 'MAP')
+        ) {
             return;
         }
         else {
