@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Writer;
 
-our $VERSION = '0.006_002'; # TRIAL VERSION
+our $VERSION = '0.006_003'; # TRIAL VERSION
 
 sub output { return $_[0]->{output} }
 sub set_output { $_[0]->{output} = $_[1] }
@@ -21,6 +21,11 @@ sub write {
     $self->{output} .= $line;
 }
 
+sub finish {
+    my ($self) = @_;
+    $self->{output} = undef;
+}
+
 package YAML::PP::Writer::File;
 
 our @ISA = qw/ YAML::PP::Writer /;
@@ -42,4 +47,9 @@ sub write {
     print $fh $line;
 }
 
+sub finish {
+    my ($self) = @_;
+    close $self->{filehandle};
+}
+
 1;
